Address

Struct Address 

pub struct Address {
    pub function_type: FunctionType,
    pub id: String,
}
The unique identity of an individual stateful function.

This comprises the function’s FunctionType and an unique identifier within the type. The function’s type denotes the class of function to invoke, while the unique identifier addresses the invocation to a specific function instance.

This must be used when sending messages to stateful functions as part of the function Effects.

Fields

function_type: FunctionType

FunctionType of the stateful function that this Address refers to.

id: String

Unique id of the stateful function that this Address refers to.

Implementations

Source

impl Address

pub fn new(function_type: FunctionType, id: &str) -> Self

Creates a new Address from the given FunctionType and id.