pub struct HyperHttpTransport { /* private fields */ }Expand description
A Transport that serves stateful functions on a http endpoint at
the given bind_address.
Implementations
Sourceimpl HyperHttpTransport
impl HyperHttpTransport
Sourcepub fn new(bind_address: SocketAddr) -> HyperHttpTransport
pub fn new(bind_address: SocketAddr) -> HyperHttpTransport
Creates a new HyperHttpTransport that can serve stateful functions at the given
bind_address.